==> gorilla-notes-0.4.0-20200914.094953-4.jar: public/js/compiled/cljs-runtime/module$node_modules$react_player$lib$players$Vimeo.js <==
import "./cljs_env.js";
shadow$provide.module$node_modules$react_player$lib$players$Vimeo=function(global,require,module,exports){function _getRequireWildcardCache(){if("function"!==typeof WeakMap)return null;var cache=new WeakMap;_getRequireWildcardCache=function(){return cache};return cache}function _typeof(obj$jscomp$0){"@babel/helpers - typeof";_typeof="function"===typeof Symbol&&"symbol"===typeof Symbol.iterator?function(obj){return typeof obj}:function(obj){return obj&&"function"===typeof Symbol&&obj.constructor===
Symbol&&obj!==Symbol.prototype?"symbol":typeof obj};return _typeof(obj$jscomp$0)}function ownKeys(object,enumerableOnly){var keys=Object.keys(object);if(Object.getOwnPropertySymbols){var symbols=Object.getOwnPropertySymbols(object);enumerableOnly&&(symbols=symbols.filter(function(sym){return Object.getOwnPropertyDescriptor(object,sym).enumerable}));keys.push.apply(keys,symbols)}return keys}function _objectSpread(target){for(var i=1;i<arguments.length;i++){var source=null!=arguments[i]?arguments[i]:
{};i%2?ownKeys(Object(source),!0).forEach(function(key){_defineProperty(target,key,source[key])}):Object.getOwnPropertyDescriptors?Object.defineProperties(target,Object.getOwnPropertyDescriptors(source)):ownKeys(Object(source)).forEach(function(key){Object.defineProperty(target,key,Object.getOwnPropertyDescriptor(source,key))})}return target}function _defineProperties(target,props){for(var i=0;i<props.length;i++){var descriptor=props[i];descriptor.enumerable=descriptor.enumerable||!1;descriptor.configurable=
!0;"value"in descriptor&&(descriptor.writable=!0);Object.defineProperty(target,descriptor.key,descriptor)}}function _createClass(Constructor,protoProps,staticProps){protoProps&&_defineProperties(Constructor.prototype,protoProps);staticProps&&_defineProperties(Constructor,staticProps);return Constructor}function _createSuper(Derived){return function(){var Super=_getPrototypeOf(Derived);if(_isNativeReflectConstruct()){var NewTarget=_getPrototypeOf(this).constructor;Super=Reflect.construct(Super,arguments,
NewTarget)}else Super=Super.apply(this,arguments);Super=!Super||"object"!==_typeof(Super)&&"function"!==typeof Super?_assertThisInitialized(this):Super;return Super}}function _assertThisInitialized(self){if(void 0===self)throw new ReferenceError("this hasn't been initialised - super() hasn't been called");return self}function _isNativeReflectConstruct(){if("undefined"===typeof Reflect||!Reflect.construct||Reflect.construct.sham)return!1;if("function"===typeof Proxy)return!0;try{return Date.prototype.toString.call(Reflect.construct(Date,
[],function(){})),!0}catch(e){return!1}}function _getPrototypeOf(o$jscomp$0){_getPrototypeOf=Object.setPrototypeOf?Object.getPrototypeOf:function(o){return o.__proto__||Object.getPrototypeOf(o)};return _getPrototypeOf(o$jscomp$0)}function _inherits(subClass,superClass){if("function"!==typeof superClass&&null!==superClass)throw new TypeError("Super expression must either be null or a function");subClass.prototype=Object.create(superClass&&superClass.prototype,{constructor:{value:subClass,writable:!0,
configurable:!0}});superClass&&_setPrototypeOf(subClass,superClass)}function _setPrototypeOf(o$jscomp$0,p$jscomp$0){_setPrototypeOf=Object.setPrototypeOf||function(o,p){o.__proto__=p;return o};return _setPrototypeOf(o$jscomp$0,p$jscomp$0)}function _defineProperty(obj,key,value){key in obj?Object.defineProperty(obj,key,{value,enumerable:!0,configurable:!0,writable:!0}):obj[key]=value;return obj}Object.defineProperty(exports,"__esModule",{value:!0});exports["default"]=exports.Vimeo=void 0;var _react=
function(obj){if(obj&&obj.__esModule)return obj;if(null===obj||"object"!==_typeof(obj)&&"function"!==typeof obj)return{"default":obj};var cache=_getRequireWildcardCache();if(cache&&cache.has(obj))return cache.get(obj);var newObj={},hasPropertyDescriptor=Object.defineProperty&&Object.getOwnPropertyDescriptor,key;for(key in obj)if(Object.prototype.hasOwnProperty.call(obj,key)){var desc=hasPropertyDescriptor?Object.getOwnPropertyDescriptor(obj,key):null;desc&&(desc.get||desc.set)?Object.defineProperty(newObj,
key,desc):newObj[key]=obj[key]}newObj["default"]=obj;cache&&cache.set(obj,newObj);return newObj}(require("module$node_modules$react$index")),_utils=require("module$node_modules$react_player$lib$utils");global=function(obj){return obj&&obj.__esModule?obj:{"default":obj}}(require("module$node_modules$react_player$lib$singlePlayer"));var MATCH_URL=/vimeo\.com\/.+/,MATCH_FILE_URL=/vimeo\.com\/external\/[0-9]+\..+/;require=function(_Component){function Vimeo$jscomp$0(){if(!(this instanceof Vimeo$jscomp$0))throw new TypeError("Cannot call a class as a function");
for(var _len=arguments.length,args=Array(_len),_key=0;_key<_len;_key++)args[_key]=arguments[_key];var _this=_super.call.apply(_super,[this].concat(args));_defineProperty(_assertThisInitialized(_this),"callPlayer",_utils.callPlayer);_defineProperty(_assertThisInitialized(_this),"duration",null);_defineProperty(_assertThisInitialized(_this),"currentTime",null);_defineProperty(_assertThisInitialized(_this),"secondsLoaded",null);_defineProperty(_assertThisInitialized(_this),"mute",function(){_this.setVolume(0)});
_defineProperty(_assertThisInitialized(_this),"unmute",function(){null!==_this.props.volume&&_this.setVolume(_this.props.volume)});_defineProperty(_assertThisInitialized(_this),"ref",function(container){_this.container=container});return _this}_inherits(Vimeo$jscomp$0,_Component);var _super=_createSuper(Vimeo$jscomp$0);_createClass(Vimeo$jscomp$0,[{key:"load",value:function(url){var _this2=this;this.duration=null;(0,_utils.getSDK)("https://player.vimeo.com/api/player.js","Vimeo").then(function(Vimeo){_this2.container&&
(_this2.player=new Vimeo.Player(_this2.container,_objectSpread({url,autoplay:_this2.props.playing,muted:_this2.props.muted,loop:_this2.props.loop,playsinline:_this2.props.playsinline,controls:_this2.props.controls},_this2.props.config.vimeo.playerOptions)),_this2.player.ready().then(function(){var iframe=_this2.container.querySelector("iframe");iframe.style.width="100%";iframe.style.height="100%"})["catch"](_this2.props.onError),_this2.player.on("loaded",function(){_this2.props.onReady();_this2.refreshDuration()}),
_this2.player.on("play",function(){_this2.props.onPlay();_this2.refreshDuration()}),_this2.player.on("pause",_this2.props.onPause),_this2.player.on("seeked",function(e){return _this2.props.onSeek(e.seconds)}),_this2.player.on("ended",_this2.props.onEnded),_this2.player.on("error",_this2.props.onError),_this2.player.on("timeupdate",function(_ref){_this2.currentTime=_ref.seconds}),_this2.player.on("progress",function(_ref2){_this2.secondsLoaded=_ref2.seconds}))},this.props.onError)}},{key:"refreshDuration",
value:function(){var _this3=this;this.player.getDuration().then(function(duration){_this3.duration=duration})}},{key:"play",value:function(){var promise=this.callPlayer("play");if(promise)promise["catch"](this.props.onError)}},{key:"pause",value:function(){this.callPlayer("pause")}},{key:"stop",value:function(){this.callPlayer("unload")}},{key:"seekTo",value:function(seconds){this.callPlayer("setCurrentTime",seconds)}},{key:"setVolume",value:function(fraction){this.callPlayer("setVolume",fraction)}},
{key:"setLoop",value:function(loop){this.callPlayer("setLoop",loop)}},{key:"setPlaybackRate",value:function(rate){this.callPlayer("setPlaybackRate",rate)}},{key:"getDuration",value:function(){return this.duration}},{key:"getCurrentTime",value:function(){return this.currentTime}},{key:"getSecondsLoaded",value:function(){return this.secondsLoaded}},{key:"render",value:function(){return _react["default"].createElement("div",{key:this.props.url,ref:this.ref,style:{width:"100%",height:"100%",overflow:"hidden",
display:this.props.display}})}}]);return Vimeo$jscomp$0}(_react.Component);exports.Vimeo=require;_defineProperty(require,"displayName","Vimeo");_defineProperty(require,"forceLoad",!0);_defineProperty(require,"canPlay",function(url){return MATCH_FILE_URL.test(url)?!1:MATCH_URL.test(url)});global=(0,global["default"])(require);exports["default"]=global}
//# sourceMappingURL=module$node_modules$react_player$lib$players$Vimeo.js.map

==> gorilla-notes-0.5.0-20201009.234502-4.jar: public/js/compiled/cljs-runtime/module$node_modules$react_player$lib$players$Vimeo.js <==
shadow$provide.module$node_modules$react_player$lib$players$Vimeo=function(global,require,module,exports){function _getRequireWildcardCache(){if("function"!==typeof WeakMap)return null;var cache=new WeakMap;_getRequireWildcardCache=function(){return cache};return cache}function _typeof(obj$jscomp$0){"@babel/helpers - typeof";_typeof="function"===typeof Symbol&&"symbol"===typeof Symbol.iterator?function(obj){return typeof obj}:function(obj){return obj&&"function"===typeof Symbol&&obj.constructor===
Symbol&&obj!==Symbol.prototype?"symbol":typeof obj};return _typeof(obj$jscomp$0)}function ownKeys(object,enumerableOnly){var keys=Object.keys(object);if(Object.getOwnPropertySymbols){var symbols=Object.getOwnPropertySymbols(object);enumerableOnly&&(symbols=symbols.filter(function(sym){return Object.getOwnPropertyDescriptor(object,sym).enumerable}));keys.push.apply(keys,symbols)}return keys}function _objectSpread(target){for(var i=1;i<arguments.length;i++){var source=null!=arguments[i]?arguments[i]:
{};i%2?ownKeys(Object(source),!0).forEach(function(key){_defineProperty(target,key,source[key])}):Object.getOwnPropertyDescriptors?Object.defineProperties(target,Object.getOwnPropertyDescriptors(source)):ownKeys(Object(source)).forEach(function(key){Object.defineProperty(target,key,Object.getOwnPropertyDescriptor(source,key))})}return target}function _defineProperties(target,props){for(var i=0;i<props.length;i++){var descriptor=props[i];descriptor.enumerable=descriptor.enumerable||!1;descriptor.configurable=
!0;"value"in descriptor&&(descriptor.writable=!0);Object.defineProperty(target,descriptor.key,descriptor)}}function _createClass(Constructor,protoProps,staticProps){protoProps&&_defineProperties(Constructor.prototype,protoProps);staticProps&&_defineProperties(Constructor,staticProps);return Constructor}function _createSuper(Derived){return function(){var Super=_getPrototypeOf(Derived);if(_isNativeReflectConstruct()){var NewTarget=_getPrototypeOf(this).constructor;Super=Reflect.construct(Super,arguments,
NewTarget)}else Super=Super.apply(this,arguments);Super=!Super||"object"!==_typeof(Super)&&"function"!==typeof Super?_assertThisInitialized(this):Super;return Super}}function _assertThisInitialized(self){if(void 0===self)throw new ReferenceError("this hasn't been initialised - super() hasn't been called");return self}function _isNativeReflectConstruct(){if("undefined"===typeof Reflect||!Reflect.construct||Reflect.construct.sham)return!1;if("function"===typeof Proxy)return!0;try{return Date.prototype.toString.call(Reflect.construct(Date,
[],function(){})),!0}catch(e){return!1}}function _getPrototypeOf(o$jscomp$0){_getPrototypeOf=Object.setPrototypeOf?Object.getPrototypeOf:function(o){return o.__proto__||Object.getPrototypeOf(o)};return _getPrototypeOf(o$jscomp$0)}function _inherits(subClass,superClass){if("function"!==typeof superClass&&null!==superClass)throw new TypeError("Super expression must either be null or a function");subClass.prototype=Object.create(superClass&&superClass.prototype,{constructor:{value:subClass,writable:!0,
configurable:!0}});superClass&&_setPrototypeOf(subClass,superClass)}function _setPrototypeOf(o$jscomp$0,p$jscomp$0){_setPrototypeOf=Object.setPrototypeOf||function(o,p){o.__proto__=p;return o};return _setPrototypeOf(o$jscomp$0,p$jscomp$0)}function _defineProperty(obj,key,value){key in obj?Object.defineProperty(obj,key,{value:value,enumerable:!0,configurable:!0,writable:!0}):obj[key]=value;return obj}Object.defineProperty(exports,"__esModule",{value:!0});exports["default"]=exports.Vimeo=void 0;var _react=
function(obj){if(obj&&obj.__esModule)return obj;if(null===obj||"object"!==_typeof(obj)&&"function"!==typeof obj)return{"default":obj};var cache=_getRequireWildcardCache();if(cache&&cache.has(obj))return cache.get(obj);var newObj={},hasPropertyDescriptor=Object.defineProperty&&Object.getOwnPropertyDescriptor,key;for(key in obj)if(Object.prototype.hasOwnProperty.call(obj,key)){var desc=hasPropertyDescriptor?Object.getOwnPropertyDescriptor(obj,key):null;desc&&(desc.get||desc.set)?Object.defineProperty(newObj,
key,desc):newObj[key]=obj[key]}newObj["default"]=obj;cache&&cache.set(obj,newObj);return newObj}(require("module$node_modules$react$index")),_utils=require("module$node_modules$react_player$lib$utils");global=function(obj){return obj&&obj.__esModule?obj:{"default":obj}}(require("module$node_modules$react_player$lib$singlePlayer"));var MATCH_URL=/vimeo\.com\/.+/,MATCH_FILE_URL=/vimeo\.com\/external\/[0-9]+\..+/;require=function(_Component){function Vimeo$jscomp$0(){if(!(this instanceof Vimeo$jscomp$0))throw new TypeError("Cannot call a class as a function");
for(var _len=arguments.length,args=Array(_len),_key=0;_key<_len;_key++)args[_key]=arguments[_key];var _this=_super.call.apply(_super,[this].concat(args));_defineProperty(_assertThisInitialized(_this),"callPlayer",_utils.callPlayer);_defineProperty(_assertThisInitialized(_this),"duration",null);_defineProperty(_assertThisInitialized(_this),"currentTime",null);_defineProperty(_assertThisInitialized(_this),"secondsLoaded",null);_defineProperty(_assertThisInitialized(_this),"mute",function(){_this.setVolume(0)});
_defineProperty(_assertThisInitialized(_this),"unmute",function(){null!==_this.props.volume&&_this.setVolume(_this.props.volume)});_defineProperty(_assertThisInitialized(_this),"ref",function(container){_this.container=container});return _this}_inherits(Vimeo$jscomp$0,_Component);var _super=_createSuper(Vimeo$jscomp$0);_createClass(Vimeo$jscomp$0,[{key:"load",value:function(url){var _this2=this;this.duration=null;(0,_utils.getSDK)("https://player.vimeo.com/api/player.js","Vimeo").then(function(Vimeo){_this2.container&&
(_this2.player=new Vimeo.Player(_this2.container,_objectSpread({url:url,autoplay:_this2.props.playing,muted:_this2.props.muted,loop:_this2.props.loop,playsinline:_this2.props.playsinline,controls:_this2.props.controls},_this2.props.config.vimeo.playerOptions)),_this2.player.ready().then(function(){var iframe=_this2.container.querySelector("iframe");iframe.style.width="100%";iframe.style.height="100%"})["catch"](_this2.props.onError),_this2.player.on("loaded",function(){_this2.props.onReady();_this2.refreshDuration()}),
_this2.player.on("play",function(){_this2.props.onPlay();_this2.refreshDuration()}),_this2.player.on("pause",_this2.props.onPause),_this2.player.on("seeked",function(e){return _this2.props.onSeek(e.seconds)}),_this2.player.on("ended",_this2.props.onEnded),_this2.player.on("error",_this2.props.onError),_this2.player.on("timeupdate",function(_ref){_this2.currentTime=_ref.seconds}),_this2.player.on("progress",function(_ref2){_this2.secondsLoaded=_ref2.seconds}))},this.props.onError)}},{key:"refreshDuration",
value:function(){var _this3=this;this.player.getDuration().then(function(duration){_this3.duration=duration})}},{key:"play",value:function(){var promise=this.callPlayer("play");if(promise)promise["catch"](this.props.onError)}},{key:"pause",value:function(){this.callPlayer("pause")}},{key:"stop",value:function(){this.callPlayer("unload")}},{key:"seekTo",value:function(seconds){this.callPlayer("setCurrentTime",seconds)}},{key:"setVolume",value:function(fraction){this.callPlayer("setVolume",fraction)}},
{key:"setLoop",value:function(loop){this.callPlayer("setLoop",loop)}},{key:"setPlaybackRate",value:function(rate){this.callPlayer("setPlaybackRate",rate)}},{key:"getDuration",value:function(){return this.duration}},{key:"getCurrentTime",value:function(){return this.currentTime}},{key:"getSecondsLoaded",value:function(){return this.secondsLoaded}},{key:"render",value:function(){return _react["default"].createElement("div",{key:this.props.url,ref:this.ref,style:{width:"100%",height:"100%",overflow:"hidden",
display:this.props.display}})}}]);return Vimeo$jscomp$0}(_react.Component);exports.Vimeo=require;_defineProperty(require,"displayName","Vimeo");_defineProperty(require,"forceLoad",!0);_defineProperty(require,"canPlay",function(url){return MATCH_FILE_URL.test(url)?!1:MATCH_URL.test(url)});global=(0,global["default"])(require);exports["default"]=global}
//# sourceMappingURL=module$node_modules$react_player$lib$players$Vimeo.js.map
